-- This function populates the fact_contact table, based on the staging
-- area tables. This function should NOT be called directly.
CREATE OR REPLACE FUNCTION load_fact_contact() returns void as $$
DECLARE
	result RECORD;
	start_ts TIMESTAMP;
	total_rows INTEGER;
BEGIN

	-- getting initial timestamp
	start_ts = CLOCK_TIMESTAMP();

	-- getting the date limits
	SELECT max(contact_date) as max_date, min(contact_date) as min_date 
		INTO result from sa_inventory;

	-- 
	INSERT INTO fact_contact (tl_id, cit_id, dat_id, macaddr, machine_type)
	(SELECT tl_id, cit_id, contact_date, macaddr::macaddr, to_machine_type_enum(machine_type) FROM sa_inventory WHERE valid = '1')
	EXCEPT
	(SELECT tl_id, cit_id, dat_id, macaddr, machine_type FROM fact_contact WHERE dat_id >= result.min_date AND dat_id <= result.max_date);

	-- how many rows were inserted?
	GET DIAGNOSTICS total_rows = ROW_COUNT;

	-- logging
	INSERT INTO control (name, start_time, end_time, total) 
		VALUES ('loading fact contact', start_ts, CLOCK_TIMESTAMP(), total_rows);

END;
$$ language plpgsql;
