'use strict';

angular.module('datasid', ['ngResource', 'ui.router', 'datasid.install', 'datasid.doc', 'datasid.attendance', 'datasid.attendance.search']).
    config(function($stateProvider, $httpProvider) {
        $stateProvider.
            state('index', {
                url: '',
                templateUrl: 'partials/index.html',
            });
    }).

    directive('mcActiveClass', function($animate) {
        return function (scope, element, attrs) {
            scope.$watch(attrs.mcActiveClass, function (value) {
                $animate[toBoolean(value) ? 'addClass' : 'removeClass'](element, 'active');
            });
        }
    }).

    directive('mcCollapsedClass', function($animate) {
        return function (scope, element, attrs) {
            scope.$watch(attrs.mcCollapsedClass, function (value) {
                $animate[toBoolean(value) ? 'addClass' : 'removeClass'](element, 'collapsed');
            });
        }
    }).

    directive('mcChart', function() {
        return function (scope, element, attrs) {
            scope[attrs.mcChart].render(element);
        }
    }).

    factory('SessionFactory', function ($resource) {
        return $resource('/api/s');
    }).

    controller('MainCtrl', function ($scope, $rootScope, $state, SessionFactory) {
        $scope.bigButtons = {
            collapsed: false,
            rowClass: "",
            order: "",
            current: null,
            items: [
                {
                    title: "Acompanhamento",
                    icon: "icon-charts",
                    color: "dark",
                    link: "#/attendance",
                    section: "attendance",
                    active: false
                },
                {
                    title: "Instalação",
                    icon: "icon-install",
                    color: "medium",
                    link: "#/install",
                    section: "install",
                    active: false
                },
                {
                    title: "Documentação",
                    icon: "icon-doc",
                    color: "light",
                    link: "#/doc",
                    section: "doc",
                    active: false
                },
            ],
        };

        $scope.login = {
            includeUrl: '',
            error: null,
            loading: false,
            username: 'admin',
            password: '123mudar',
            buttonText: 'Acesso Restrito',
            click: function () {
                if ($scope.session.loggedIn)
                    this.logout();
                else
                    this.show();
            },
            show: function () {
                this.includeUrl = 'partials/login.html';
            },
            hide: function () {
                this.includeUrl = '';
            },
            submit: function () {
                this.loading = true;
                this.error = null;

                SessionFactory.save({username: $scope.login.username, password: $scope.login.password}, function (session) {
                    $scope.login.loading = false;

                    $scope.session = session;
                    $rootScope.$broadcast('$sessionUpdate', session);

                    if (session.error) {
                        $scope.login.error = 'Usuário ou senha inválidos.';
                        return;
                    }

                    $scope.login.username = '';
                    $scope.login.password = '';
                    $scope.login.hide();
                }, function (response) {
                    $scope.login.loading = false;

                    if ((typeof response.data.error !== 'undefined') &&
                        (response.data.error === 'invalid_username_password'))
                        $scope.login.error = 'Usuário ou senha inválidos.';
                    else
                        $scope.login.error = 'Erro no servidor, tente novamente mais tarde.';
                });
            },
            cancel: function () {
                this.error = null;
                this.loading = false;
                this.username = '';
                this.password = '';
                this.hide();
            },
            logout: function () {
                SessionFactory.delete(function(session) {
                    $scope.session = session;
                    $rootScope.$broadcast('$sessionUpdate', session);
                });
            }
        };

        SessionFactory.get(function (session) {
            $scope.session = session;
            $rootScope.$broadcast('$sessionUpdate', session);
        });

        $scope.$on('$accessDenied', function (e) {
            SessionFactory.get(function (session) {
                $scope.session = session;
                $rootScope.$broadcast('$sessionUpdate', session);
            });
        });

        $scope.$on('$sessionUpdate', function (e, newSession) {
            if (newSession.loggedIn)
                $scope.login.buttomText = "Logout";
            else
                $scope.login.buttomText = "Acesso Restrito";
        });

        $scope.$on("$stateChangeSuccess", function(event, toState, toParams, fromState, fromParams) {
            if (typeof $state.current === "undefined")
                return;

            if (!("section" in $state.current)) {
                $scope.bigButtons.collapsed = false;
                $scope.bigButtons.order = "";
            }
            else {
                $scope.bigButtons.collapsed = true;
                $scope.bigButtons.order = "-active";

                angular.forEach($scope.bigButtons.items, function (item) {
                    item.active = (item.section === $state.current.section);
                    if (item.active) {
                        $scope.bigButtons.current = item;
                        $scope.bigButtons.rowClass = item.color;
                    }
                });
            }
        });
    });