import java.io.*;
import java.util.*;

import java.sql.DriverManager;
import java.sql.Connection;
import java.sql.SQLException;

import net.sf.jasperreports.engine.*;
import net.sf.jasperreports.engine.export.*;

public class ReportBuilder {
    private static String IMAGES_PATH = "./images/";

    public static void main(String args[]) {
        Properties prop = new Properties();
        Connection connection = null;
        JRExporter exporter = new JRPdfExporter();
        JasperReport report;
        JasperPrint print;
        Map params = new HashMap();

        try {
            prop.load(new FileInputStream("config.properties"));
        }
        catch (IOException e) {
            System.err.println("Failed to load config.properties");
            e.printStackTrace();
            return;
        }

        try {
            report = JasperCompileManager.compileReport(args[0]);
        }
        catch (JRException e) {
            System.err.println("Failed to compile report!");
            e.printStackTrace();
            return;
        }

        params.put("ID_CITY", Integer.parseInt(args[1]));
        params.put("imagesPath", IMAGES_PATH);

        try {
            Class.forName("org.postgresql.Driver");
        }
        catch (ClassNotFoundException e) {
            System.err.println("Failed to load postgresql JDBC driver!");
            e.printStackTrace();
            return;
        }

        try {
            connection = DriverManager.getConnection(
                "jdbc:postgresql://" + prop.getProperty("host")+
                    ":" + prop.getProperty("port") +
                    "/" + prop.getProperty("database"),
                prop.getProperty("username"),
                prop.getProperty("password")
            );

            print = JasperFillManager.fillReport(report, params, connection);

            connection.close();
        }
        catch (SQLException e) {
            System.err.println("Failed to fill report (database error)!");
            e.printStackTrace();
            return;
        }
        catch (JRException e) {
            System.err.println("Failed to fill report (report error)!");
            e.printStackTrace();
            return;
        }

        try {
            exporter.setParameter(JRExporterParameter.OUTPUT_STREAM, System.out);
            exporter.setParameter(JRExporterParameter.JASPER_PRINT, print);
            exporter.exportReport();
        }
        catch (JRException e) {
            System.err.println("Failed to export report to pdf!");
            e.printStackTrace();
            return;
        }
    }
}
