function parseParams(req) {
    var c = 1, filters, sort, offset, conditions = [], parameters = [], where = "";

    filters = req.body.filters || {};

    var sortParams = [];
    switch (req.body.sorting) {
        case "name":        sortParams = ["pt.name", "ASC"]; break;
        case "-name":       sortParams = ["pt.name", "DESC"]; break;
        case "project":     sortParams = ["pt.project", "ASC"]; break;
        case "-project":    sortParams = ["pt.project", "DESC"]; break;
        case "location":    sortParams = ["ct.name||ct.state", "ASC"]; break;
        case "-location":   sortParams = ["ct.name||ct.state", "DESC"]; break;
        default:            sortParams = ["pt.name", "ASC"]; break;
    }

    var sort = "LOWER(remove_accentuation("
                + sortParams[0] + ")) " + sortParams[1];

    offset = (req.body.page || 0) * 50;

    for (var key in filters) {
        switch (key) {
        case "project":
            var l = [];
            for (var i = 0; i < filters[key].length; i++) {
                l.push("pt.project = $"+(c++));
                parameters.push(filters[key][i]);
            }
            if (l.length > 0)
                conditions.push(l.join(' OR '));
            break;
        case "location":
            var l = [];
            for (var i = 0; i < filters[key].length; i++) {
                l.push("pt.id_city = $"+(c++));
                parameters.push(filters[key][i]);
            }
            if (l.length > 0)
                conditions.push(l.join(' OR '));
            break;
        }
    }

    if (conditions.length > 0)
        where = " AND (" + conditions.join(') AND (') + ")";

    return {
        where: where,
        sort: sort,
        offset: offset,
        parameters: parameters
    };
}

exports.list = function(req, res) {
    var params = parseParams(req);

    var query = "\
        SELECT \
            pt.id, \
            pt.name, \
            pt.project, \
            pt.id_city, \
            initcap(ct.name) || ', ' || upper(ct.state) AS location \
            FROM \
                (SELECT \
                    t.id_point AS id, \
                    t.name, \
                    p.id_city, \
                    CASE WHEN p.is_gesac THEN 'TLBR/GESAC' ELSE 'TLBR' END AS project \
                    FROM telecenter t, point p \
                    WHERE t.id_point = p.id \
                UNION \
                SELECT \
                    id_point AS id, \
                    establishment AS name, \
                    p.id_city, \
                    'GESAC' AS project \
                    FROM convention c, point p \
                    WHERE c.id_point = p.id) pt, city ct \
            WHERE pt.id_city = ct.id " + params.where + " \
            ORDER BY " + params.sort + " \
            LIMIT 50 \
            OFFSET " + params.offset;

    req.db.query(query, params.parameters, function(result) {
        req.db.done();
        res.json(result.rows);
    });
};

exports.count = function(req, res) {
    var params = parseParams(req);

    var query = "\
        SELECT \
            COUNT(*) AS count \
            FROM \
                (SELECT \
                    t.id_point AS id, \
                    t.name, \
                    p.id_city, \
                    CASE WHEN p.is_gesac THEN 'TLBR/GESAC' ELSE 'TLBR' END AS project \
                    FROM telecenter t, point p \
                    WHERE t.id_point = p.id \
                UNION \
                SELECT \
                    id_point AS id, \
                    establishment AS name, \
                    p.id_city, \
                    'GESAC' AS project \
                    FROM convention c, point p \
                    WHERE c.id_point = p.id) pt, city ct \
            WHERE pt.id_city = ct.id " + params.where;

    req.db.query(query, params.parameters, function(result) {
        req.db.done();

        if (result.rows.length < 1)
            return res.json(500, {error: 'db_query_failed'});

        var count = result.rows[0].count;
        res.json({count: count, pageCount: Math.ceil(count / 50)});
    });
};
