#!/usr/bin/env node

var express = require('express');
var config = require('./config.js');
var db = require('./middleware/db.js');

var sessions = require('./routes/sessions.js');
var points = require('./routes/points.js');
var telecenters = require('./routes/telecenters.js');
var charts = require('./routes/charts.js');

var port = parseInt(process.argv.splice(2)[0]) || 3000;

var app = express();
app.use(express.logger('dev'));
app.use(express.bodyParser());
app.use(express.cookieParser());
app.use(express.session({ secret: config.secret }));
app.use(express.static(__dirname + '/app'));

db.config(config.db_config);

app.post('/api/s', sessions.login);
app.get('/api/s', sessions.get);
app.delete('/api/s', sessions.logout);

app.all('/api/points', db.connect, points.list);
app.all('/api/points/count', db.connect, points.count);

app.all('/api/telecenters/:state?/:city_id?/:telecenter_id?', db.connect, telecenters.list);

app.get('/api/reports/:project/:type/:id_city', db.connect, charts.get_report);

app.get('/api/:project/:type', db.connect, charts.get_data);
app.get('/api/:project/:type/:region', db.connect, charts.get_data);
app.get('/api/:project/:type/:region/:state', db.connect, charts.get_data);
app.get('/api/:project/:type/:region/:state/:id_city', db.connect, charts.get_data);
app.get('/api/:project/:type/:region/:state/:id_city/:id_point', db.connect, charts.get_data);

app.listen(port);
